@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 import logging
 
-logger = logging.getLogger('vindauga.menus.menu')
+logger = logging.getLogger(__name__)
 
 
 class Menu:
