@@ -1,12 +1,13 @@
 # -*- coding: utf-8 -*-
 import logging
+from typing import Union
 
 from vindauga.constants.command_codes import hcNoContext
 
 from .menu import Menu
 from .menu_item import MenuItem
 
-logger = logging.getLogger('vindauga.menu.sub_menu')
+logger = logging.getLogger(__name__)
 
 
 class SubMenu(MenuItem):
@@ -23,14 +24,14 @@ class SubMenu(MenuItem):
     def __repr__(self):
         return "<SubMenu: {0.name}>".format(self)
 
-    def __add__(self, other):
+    def __add__(self, other: Union['SubMenu', MenuItem]):
         if isinstance(other, SubMenu):
             self.__addSubMenu(other)
         elif isinstance(other, MenuItem):
             self.__addMenuItem(other)
         return self
 
-    def __addMenuItem(self, menu):
+    def __addMenuItem(self, menu: MenuItem):
         sub = self
         while sub.next:
             sub = sub.next
@@ -43,7 +44,7 @@ class SubMenu(MenuItem):
                 cur = cur.next
             cur.next = menu
 
-    def __addSubMenu(self, other):
+    def __addSubMenu(self, other: 'SubMenu'):
         cur = self
         while cur.next:
             cur = cur.next
