@@ -29,6 +29,7 @@ from .draw_buffer import BufferArray, DrawBuffer
 from .display import Display
 from .mouse_event import MouseEvent
 from .point import Point
+from .key_mapping import get_key_mapping
 
 PLATFORM_IS_WINDOWS = platform.system().lower() == 'windows'
 
@@ -43,7 +44,7 @@ else:
 
     HAS_IOCTL = 'TIOCLINUX' in dir(termios)
 
-logger = logging.getLogger('vindauga.types.screen')
+logger = logging.getLogger(__name__)
 
 BUTTON_PRESSED = (curses.BUTTON1_PRESSED |
                   curses.BUTTON2_PRESSED |
@@ -140,9 +141,10 @@ class TScreen:
         return TScreen.evQueue.qsize()
 
     @staticmethod
-    def kbReadShiftState():
+    def kbReadShiftState(ch):
+        shift = 0
         if not HAS_IOCTL:
-            return 0
+            return get_key_mapping(ch)
         arg = 6
         shift = 0
         try:
@@ -157,8 +159,8 @@ class TScreen:
             if arg & 1:
                 shift |= kbLeftShift | kbRightShift
         except OSError:
-            return 0
-        return shift
+            return get_key_mapping(ch)
+        return ch, shift
 
     @staticmethod
     def kbMapKey(code, eventType, modifiers):
@@ -192,6 +194,7 @@ class TScreen:
         curses.noecho()
         curses.cbreak()
         stdscr.keypad(True)
+        stdscr.nodelay(True)
         try:
             curses.start_color()
             curses.use_default_colors()
@@ -199,11 +202,12 @@ class TScreen:
             pass
         atexit.register(self.shutdown)
         curses.mousemask(curses.ALL_MOUSE_EVENTS)
-        sys.stderr = os.devnull
+        sys.stderr = open(os.devnull, 'wt')
         return stdscr
 
     def shutdown(self):
         sys.stderr = sys.__stderr__
+        self.stdscr.nodelay(False)
         self.stdscr.keypad(False)
         curses.echo()
         curses.nocbreak()
@@ -349,8 +353,10 @@ class TScreen:
                 keyType = TALT
                 modifiers = 0
         else:
-            modifiers = self.kbReadShiftState()
+            code, modifiers = self.kbReadShiftState(code)
+
         code = self.kbMapKey(code, keyType, modifiers)
+
         if code != kbNoKey:
             event = Event(evKeyDown)
             event.keyDown.keyCode = code
@@ -360,15 +366,16 @@ class TScreen:
     def selectPalette(self):
         if curses.can_change_color():
             # TODO: Put the palette back the way it was
+            colorLevel = 650
             # Your powershell window is going to look pink after you exit... d8)
             curses.init_color(curses.COLOR_BLACK, 0, 0, 0)
-            curses.init_color(curses.COLOR_BLUE, 0, 0, 750)
-            curses.init_color(curses.COLOR_GREEN, 0, 750, 0)
-            curses.init_color(curses.COLOR_RED, 750, 0, 0)
-            curses.init_color(curses.COLOR_YELLOW, 750, 750, 0)
-            curses.init_color(curses.COLOR_MAGENTA, 750, 0, 750)
-            curses.init_color(curses.COLOR_CYAN, 0, 750, 750)
-            curses.init_color(curses.COLOR_WHITE, 750, 750, 750)
+            curses.init_color(curses.COLOR_BLUE, 0, 0, colorLevel)
+            curses.init_color(curses.COLOR_GREEN, 0, colorLevel, 0)
+            curses.init_color(curses.COLOR_RED, colorLevel, 0, 0)
+            curses.init_color(curses.COLOR_YELLOW, colorLevel, colorLevel, 0)
+            curses.init_color(curses.COLOR_MAGENTA, colorLevel, 0, colorLevel)
+            curses.init_color(curses.COLOR_CYAN, 0, colorLevel, colorLevel)
+            curses.init_color(curses.COLOR_WHITE, colorLevel, colorLevel, colorLevel)
 
         # The color ordering is different between a CMD / Powershell window and everything else...
         if not PLATFORM_IS_WINDOWS:
