@@ -2,7 +2,7 @@
 import gettext
 import logging
 
-logger = logging.getLogger('vindauga.types.vindauga_object')
+logger = logging.getLogger(__name__)
 
 gettext.install('vindauga')
 
@@ -16,13 +16,10 @@ class VindaugaObject:
         super().__init_subclass__()
         try:
             VindaugaObject._registry[cls.name] = cls
-            logger.info('New Type: %s', cls.name)
         except AttributeError:
             logger.info('A class has no name: %s', cls)
-            pass
 
-    @staticmethod
-    def destroy(o):
+    def destroy(self, o):
         if o:
             o.shutdown()
         del o
