@@ -17,7 +17,7 @@ from vindauga.types.draw_buffer import DrawBuffer
 from vindauga.types.palette import Palette
 from vindauga.types.view import View
 
-logger = logging.getLogger('vindauga.widgets.grid_view')
+logger = logging.getLogger(__name__)
 cmUpdateItemNumber = 901
 
 
