@@ -4,7 +4,7 @@ from vindauga.types.draw_buffer import DrawBuffer
 from vindauga.types.palette import Palette
 from vindauga.types.view import View
 
-logger = logging.getLogger('vindauga.widgets.progress_bar')
+logger = logging.getLogger(__name__)
 cmStartProgress = 1000
 
 
